Flask-Sijax
####################################

Flask-Sijax is an extension for the `Flask <http://flask.pocoo.org>`_ microframework,
to simplify Sijax setup and usage for Flask users.

`Sijax <http://pypi.python.org/pypi/Sijax/>`_ is a Python/jQuery library
providing easy to use AJAX capabilities to web applications.

To learn more, refer to the included `docs` or `examples`.

